@@ -124,8 +124,11 @@ class MDocument(metaclass=MetaDocument):
     async def create(cls, *args, **kwargs):
         """Creates new document."""
 
+        query = args[0]
+        cls.Model.validate(query)
+        cls.Model.pop_optional_none(query)
         await cls.collection.insert_one(*args, **kwargs)
-        return cls(args[0])
+        return cls(query)
 
     @classmethod
     async def one(cls, query: dict, required: bool = True):
